EyebrowType enum
Eyebrow type.
Values
- angry → const EyebrowType
-
Angry eyebrows.
const EyebrowType('Angry') - angryNatural → const EyebrowType
-
Angry natural eyebrows.
const EyebrowType('Angry Natural') - defaultBrow → const EyebrowType
-
Default eyebrows.
const EyebrowType('Default') - defaultNatural → const EyebrowType
-
Default natural eyebrows.
const EyebrowType('Default Natural') - flatNatural → const EyebrowType
-
Flat natural eyebrows.
const EyebrowType('Flat Natural') - frownNatural → const EyebrowType
-
Frown natural eyebrows.
const EyebrowType('Frown Natural') - raisedExcited → const EyebrowType
-
Raised excited eyebrows.
const EyebrowType('Raised Excited') - raisedExcitedNatural → const EyebrowType
-
Raised excited natural eyebrows.
const EyebrowType('Raised Excited Natural') - sadConcerned → const EyebrowType
-
Sad concerned eyebrows.
const EyebrowType('Sad Concerned') - sadConcernedNatural → const EyebrowType
-
Sad concerned natural eyebrows.
const EyebrowType('Sad Concerned Natural') - unibrowNatural → const EyebrowType
-
Unibrow natural.
const EyebrowType('Unibrow Natural') - upDown → const EyebrowType
-
Up down eyebrows.
const EyebrowType('Up Down') - upDownNatural → const EyebrowType
-
Up down natural eyebrows.
const EyebrowType('Up Down Natural')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- label → String
-
Human-readable label.
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
EyebrowType> - A constant List of the values in this enum, in order of their declaration.